==> rechn_mgm_user_area-0.1.9.gem: app/controllers/rechn_mgm_user_area/application_controller.rb <==
module RechnMgmUserArea
    class ApplicationController < ActionController::Base
        protect_from_forgery with: :exception

        NotAuthorised = Class.new(StandardError)

        rescue_from RechnMgmUserArea::ApplicationController::NotAuthorised do
            render_error_page(status: 403, text: 'Forbidden')
        end

        before_action :add_x_frame_options if Rails.env.development?
        before_action :set_membership

        private
        def add_x_frame_options
            response.headers['X-FRAME-OPTIONS'] = 'ALLOWALL'
        end

        def set_membership
            # set membership if organisation was set by the token
            raise RechnMgmUserArea::ApplicationController::NotAuthorised if current_user.nil?

            begin
                token = Warden::JWTAuth::HeaderParser.from_env(request.headers)
                if token.nil?
                    # Seems that we were called via a session based authentication. Thus we need to set the current membership..
                    current_user.init_current_membership if current_user.current_membership_id.nil?
                    return;
                end

                payload = Warden::JWTAuth::TokenDecoder.new.call(token)
                current_user.current_membership_id = payload["membership_id"]
            rescue Exception => e
                Rails.logger.error "Token error: #{e}"
                raise RechnMgmUserArea::ApplicationController::NotAuthorised
            end
        end

        def render_error_page(status:, text:, template: 'errors/routing')
            respond_to do |format|
                format.json { render json: {errors: [message: "#{status} #{text}"]}, status: status }
                format.html { render template: template, status: status, layout: false }
                format.any  { head status }
            end
        end
    end
end

==> rechn_mgm_user_area-0.1.11.gem: app/controllers/rechn_mgm_user_area/application_controller.rb <==
module RechnMgmUserArea
    class ApplicationController < ActionController::Base
        protect_from_forgery with: :exception

        NotAuthorised = Class.new(StandardError)

        rescue_from RechnMgmUserArea::ApplicationController::NotAuthorised do
            render_error_page(status: 403, text: 'Forbidden')
        end

        before_action :add_x_frame_options if Rails.env.development?
        before_action :set_membership

        private
        def add_x_frame_options
            response.headers['X-FRAME-OPTIONS'] = 'ALLOWALL'
        end

        def set_membership
            # set membership if organisation was set by the token
            raise RechnMgmUserArea::ApplicationController::NotAuthorised if current_user.nil?

            begin
                token = Warden::JWTAuth::HeaderParser.from_env(request.headers)
                if token.nil?
                    # Seems that we were called via a session based authentication. Thus we need to set the current membership..
                    current_user.init_current_membership if current_user.current_membership_id.nil?
                    return;
                end

                payload = Warden::JWTAuth::TokenDecoder.new.call(token)
                current_user.current_membership_id = payload["membership_id"]
            rescue Exception => e
                Rails.logger.error "Token error: #{e}"
                raise RechnMgmUserArea::ApplicationController::NotAuthorised
            end
        end

        def render_error_page(status:, text:, template: 'errors/routing')
            respond_to do |format|
                format.json { render json: {errors: [message: "#{status} #{text}"]}, status: status }
                format.html { redirect_to "/logout" }
                format.any  { head status }
            end
        end
    end
end
